<p align="center">
    <img style="width: 30%; height: 30%" src="dissector-logo.png">
</p>

# Dissector


(Badges to be updated soon.)

| fair-software.eu recommendations | |
| :-- | :--  |
| (1/5) code repository              | [![github repo badge](https://img.shields.io/badge/github-repo-000.svg?logo=github&labelColor=gray&color=blue)](https://github.com/drcandacemakedamoore/dissector) |
| (2/5) license                      | [![github license badge](https://img.shields.io/github/license/drcandacemakedamoore/dissector)](https://github.com/drcandacemakedamoore/dissector) |
| (3/5) community registry           | [![RSD](https://img.shields.io/badge/rsd-dissector-00a3e3.svg)](https://www.research-software.nl/software/dissector) [![workflow pypi badge](https://img.shields.io/pypi/v/dissector.svg?colorB=blue)](https://pypi.python.org/project/dissector/) |
| (4/5) citation                     | [![DOI](https://zenodo.org/badge/DOI/<replace-with-created-DOI>.svg)](https://doi.org/<replace-with-created-DOI>)|
| (5/5) checklist                    | [![workflow cii badge](https://bestpractices.coreinfrastructure.org/projects/<replace-with-created-project-identifier>/badge)](https://bestpractices.coreinfrastructure.org/projects/<replace-with-created-project-identifier>) |
| howfairis                          | [![fair-software badge](https://img.shields.io/badge/fair--software.eu-%E2%97%8F%20%20%E2%97%8F%20%20%E2%97%8F%20%20%E2%97%8F%20%20%E2%97%8B-yellow)](https://fair-software.eu) |
| **Other best practices**           | &nbsp; |
| Static analysis                    | [![workflow scq badge](https://sonarcloud.io/api/project_badges/measure?project=drcandacemakedamoore_dissector&metric=alert_status)](https://sonarcloud.io/dashboard?id=drcandacemakedamoore_dissector) |
| Coverage                           | [![workflow scc badge](https://sonarcloud.io/api/project_badges/measure?project=drcandacemakedamoore_dissector&metric=coverage)](https://sonarcloud.io/dashboard?id=drcandacemakedamoore_dissector) || Documentation                      | [![Documentation Status](https://readthedocs.org/projects/dissector/badge/?version=latest)](https://dissector.readthedocs.io/en/latest/?badge=latest) || **GitHub Actions**                 | &nbsp; |
| Build                              | [![build](https://github.com/drcandacemakedamoore/dissector/actions/workflows/build.yml/badge.svg)](https://github.com/drcandacemakedamoore/dissector/actions/workflows/build.yml) |
| Citation data consistency          | [![cffconvert](https://github.com/drcandacemakedamoore/dissector/actions/workflows/cffconvert.yml/badge.svg)](https://github.com/drcandacemakedamoore/dissector/actions/workflows/cffconvert.yml) || SonarCloud                         | [![sonarcloud](https://github.com/drcandacemakedamoore/dissector/actions/workflows/sonarcloud.yml/badge.svg)](https://github.com/drcandacemakedamoore/dissector/actions/workflows/sonarcloud.yml) || Link checker              | [![link-check](https://github.com/drcandacemakedamoore/dissector/actions/workflows/link-check.yml/badge.svg)](https://github.com/drcandacemakedamoore/dissector/actions/workflows/link-check.yml) |## How to use dissector

Dissector is is an open-source python library which contains methods for medical image segmentation. The images
can be extracted from [DICOM](https://www.dicomstandard.org/) files or used 
directly. The primary authors are Candace Makeda H. Moore and Morris Alper.

The project setup is documented in [project_setup.md](project_setup.md). Feel free to remove this document (and/or the link to this document) if you don't need it.

## Installation

To install dissector from GitHub repository, do:

```console
git clone git@github.com:drcandacemakedamoore/dissector.git
cd dissector
python -m pip install .
```

## Documentation

There will soon be a link to our project's full documentation here.

## Contributing

If you want to contribute to the development of dissector,
have a look at the [contribution guidelines](CONTRIBUTING.md).

## Credits

This package was created with [Copier](https://github.com/copier-org/copier) and the [NLeSC/python-template](https://github.com/NLeSC/python-template).
